YARP <yarp-3.5> (UNRELEASED)                                         {#yarp_3_5}
============================

[TOC]

YARP <yarp-3.5> Release Notes
=============================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+yarp-3.5%22).

